@@ -56,6 +56,12 @@ class Event(object):
             returned["status"] = "here"
             returned["time"] = None
             returned["madechatmod"] = False
+        elif connection["event"] == "part":
+            returned["user"] = None
+            returned["text"] = None
+            returned["status"] = None
+            returned["time"] = None
+            returned ["madechatmod"] = False
         elif connection["event"] == "chat:add":
             returned["user"] = connection["data"]["attrs"]["name"]
             returned["text"] = connection["data"]["attrs"]["text"]
